@@ -9,6 +9,9 @@ Preformatted <- R6::R6Class("Preformatted",
         content=function(value) {
             if (base::missing(value))
                 return(private$.content)
+            if ( ! is.character(value))
+                value <- capture.output(value)
+            value <- paste0(value, collapse='\n')
             private$.content <- value
             private$.stale <- FALSE
             base::invisible(self)
@@ -29,6 +32,13 @@ Preformatted <- R6::R6Class("Preformatted",
                 visible=visible,
                 clearWith=clearWith)
         },
+        isFilled=function() {
+            if (private$.stale)
+                return(FALSE)
+            if (identical(private$.content, ''))
+                return(FALSE)
+            return(TRUE)
+        },
         asString=function() {
             private$.content
         },
@@ -62,4 +72,3 @@ Preformatted <- R6::R6Class("Preformatted",
         }
     )
 )
-
