@@ -336,7 +336,7 @@ nDigits <- function(x, negSign=TRUE) {
     n
 }
 
-measureElements <- function(elems, sf=3, maxdp=Inf, scl=1e-3, sch=1e7, type='number', p=FALSE, zto=FALSE) {
+measureElements <- function(elems, sf=3, maxdp=Inf, scl=1e-3, sch=1e7, type='number', p=FALSE, zto=FALSE, pc=FALSE) {
 
     # non-scientific
     dp <- 0
@@ -360,6 +360,14 @@ measureElements <- function(elems, sf=3, maxdp=Inf, scl=1e-3, sch=1e7, type='num
         sch <- Inf
     }
 
+    if (pc) {
+        dp <- sf - 2
+        maxdp <- sf - 2
+        scl <- 0
+        sch <- Inf
+        maxns <- 100
+    }
+
     for (elem in elems) {
 
         sups <- integer()
@@ -369,6 +377,9 @@ measureElements <- function(elems, sf=3, maxdp=Inf, scl=1e-3, sch=1e7, type='num
             elem <- elem$value
         }
 
+        if (pc)
+            elem <- elem * 100
+
         if (is.null(elem)) {
 
             maxstr <- max(maxstr, 1)  # width of '.'
@@ -462,7 +473,7 @@ measureElements <- function(elems, sf=3, maxdp=Inf, scl=1e-3, sch=1e7, type='num
     list(sf=sf, dp=dp, width=width, expwidth=expwidth, supwidth=maxsupwidth)
 }
 
-formatElement <- function(elem, w=NULL, expw=NULL, supw=0, dp=2, sf=3, scl=1e-3, sch=1e7, type='number', p=FALSE, zto=FALSE) {
+formatElement <- function(elem, w=NULL, expw=NULL, supw=0, dp=2, sf=3, scl=1e-3, sch=1e7, type='number', p=FALSE, zto=FALSE, pc=FALSE) {
 
     sups <- integer()
     supspad <- ''
@@ -512,7 +523,7 @@ formatElement <- function(elem, w=NULL, expw=NULL, supw=0, dp=2, sf=3, scl=1e-3,
 
         width <- nchar(elem)
         padstr <- spaces(max(w - width, 0))
-        if (type == 'number')
+        if (type == 'number' || type == 'integer')
             str <- paste0(padstr, elem)
         else
             str <- paste0(elem, padstr)
@@ -527,6 +538,9 @@ formatElement <- function(elem, w=NULL, expw=NULL, supw=0, dp=2, sf=3, scl=1e-3,
 
     } else if (elem == 0 || zto || (abs(elem) > scl && abs(elem) < sch)) {
 
+        if (pc)
+            elem <- 100 * elem
+
         # non-scientific values
         str <- sprintf(paste0("%", w, ".", dp, "f"), elem)
 
@@ -911,7 +925,6 @@ canBeNumeric <- function(object) {
 #'
 #' Note: uses the . and _ characters rather than + and / allowing these to be
 #' used as variable names
-#' @importFrom base64enc base64encode
 #' @param names the names to be converted base64
 #' @export
 toB64 <- function(names) {
@@ -927,7 +940,6 @@ toB64 <- function(names) {
 }
 
 #' @rdname toB64
-#' @importFrom base64enc base64decode
 #' @export
 fromB64 <- function(names) {
     sapply(names, function(name) {
